Method: Oso::Oso#initialize
- Defined in:
- lib/oso/oso.rb
#initialize(not_found_error: NotFoundError, forbidden_error: ForbiddenError, read_action: 'read') ⇒ Oso
Create an Oso instance, which is used to configure and enforce an Oso policy in an app.
20 21 22 23 24 25 |
# File 'lib/oso/oso.rb', line 20 def initialize(not_found_error: NotFoundError, forbidden_error: ForbiddenError, read_action: 'read') super() @not_found_error = not_found_error @forbidden_error = forbidden_error @read_action = read_action end |